% Caterpillar Diagram documentation master file, created by
% sphinx-quickstart on Sun Nov  6 19:14:18 2022.
% You can adapt this file completely to your liking, but it should at least
% contain the root `toctree` directive.


```{include} ../../README.md
```

```{warning}
This documentation is under active development. 
```

1. Read installation instructions at {ref}`Installation`.




```{toctree}
:caption: 'Contents'
:maxdepth: 4

getting_started
notebooks/tutorial
source_code_details
```

<!-- # Indices and tables

- {ref}`genindex`
- {ref}`modindex`
- {ref}`search` -->
